pub trait ApOweHandshake: Send {
// Required method
fn handle_public_key(
&mut self,
sink: &mut OweUpdateSink,
group: u16,
peer_public_key: Vec<u8>,
) -> Result<(), Error>;
}Expand description
IEEE 8021.11-2024, 12.14: Opportunistic Wireless Encryption
Required Methods
Sourcefn handle_public_key(
&mut self,
sink: &mut OweUpdateSink,
group: u16,
peer_public_key: Vec<u8>,
) -> Result<(), Error>
fn handle_public_key( &mut self, sink: &mut OweUpdateSink, group: u16, peer_public_key: Vec<u8>, ) -> Result<(), Error>
Handle the received public key from the client by generating a public/private key pair, computing the shared secret, and deriving the PMK. The AP’s public key and the PMK will be put in the update sink.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".